@@ -1,13 +1,21 @@
-
-
 class YAJLImportError(ImportError):
     pass
 
 
-def find_yajl(required):
+def require_version(version, required):
+    '''
+    Asserts that the major component of 'version' is equal to 'required'.
+    Raises YAJLImportError otherwise.
+    '''
+    major, rest = divmod(version, 10000)
+    minor, micro = divmod(rest, 100)
+    if major != required:
+        raise YAJLImportError('YAJL version %s.x required, found %s.%s.%s' % (required, major, minor, micro))
+
+def find_yajl_ctypes(required):
     '''
     Finds and loads yajl shared object of the required major
-    version (1, 2, ...).
+    version (1, 2, ...) using ctypes.
     '''
     # Importing ``ctypes`` should be in scope of this function to prevent failure
     # of `backends`` package load in a runtime where ``ctypes`` is not available.
@@ -18,8 +26,17 @@ def find_yajl(required):
     if so_name is None:
         raise YAJLImportError('YAJL shared object not found.')
     yajl = cdll.LoadLibrary(so_name)
-    major, rest = divmod(yajl.yajl_version(), 10000)
-    minor, micro = divmod(rest, 100)
-    if major != required:
-        raise YAJLImportError('YAJL version %s.x required, found %s.%s.%s' % (required, major, minor, micro))
+    require_version(yajl.yajl_version(), required)
+    return yajl
+
+def find_yajl_cffi(ffi, required):
+    '''
+    Finds and loads yajl shared object of the required major
+    version (1, 2, ...) using cffi.
+    '''
+    try:
+        yajl = ffi.dlopen('yajl')
+    except OSError:
+        raise YAJLImportError('Unable to load YAJL.')
+    require_version(yajl.yajl_version(), required)
     return yajl
